package com.itheima.json.test;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.itheima.json.domain.User;

public class JsonTest {
	
	//׼һjsonַ
	private String userStr = "{\"id\":1,\"name\":\"Ϫ\",\"birthday\":\"2010-01-01\"}";
	//׼һϵjsonַ
	private String userArr = "[{\"id\":1,\"name\":\"Ϫ\",\"birthday\":\"2010-01-01\"},"
			+ "{\"id\":2,\"name\":\"\",\"birthday\":\"2012-08-01\"}]";
	
	private User user;
	
	private List<User> users = new ArrayList<User>();
	
	@Before
	public void initUser() {
		//ʼһû
		User user = new User();
		user.setId(1);
		user.setName("");
		user.setBirthday(new Date());
		this.user = user;
		
		//ʼһ
		User user1 = new User();
		user1.setId(1);
		user1.setName("");
		user1.setBirthday(new Date());
		users.add(user1);
		
		User user2 = new User();
		user2.setId(2);
		user2.setName("Դ");
		user2.setBirthday(new Date());
		users.add(user2);
	}

	//fastjson
	@Test
	public void fastjson_json2Bean() {
		//[1-1] ʽjsonת
		User user = JSONObject.parseObject(userStr, User.class);
		System.out.println(user);
		//ӡЧ£
		//User [id=1, name=Ϫ, birthday=2010-01-01]
		
		//[1-2] ϸʽjsonת
		List<User> users = JSONArray.parseArray(userArr, User.class);
		System.out.println(users);
		//ӡЧ£
//		[User [id=1, name=Ϫ, birthday=2010-01-01], User [id=2, name=, birthday=2012-08-01]]
	}
	
	@Test
	public void fastjson_bean2Json() {
		//[1-3] תjson
		String userJson = JSONObject.toJSONString(user);
		System.out.println(userJson);
		//ӡЧ£
//		{"birthday":1530716739741,"id":1,"name":""}
		
		//[1-4] תjson
		String usersStr = JSONArray.toJSONString(users);
		System.out.println(usersStr);
		//ӡЧ£
//		[{"birthday":1530716739741,"id":1,"name":""},{"birthday":1530716739741,"id":2,"name":"Դ"}]
	}
	
	//jackson
	@Test
	public void jackson_json2Bean() throws Exception {
		//[2-1] ʽjsonת
		ObjectMapper jackson = new ObjectMapper();
		User user = jackson.readValue(userStr, User.class);
		System.out.println(user);
		//ӡ
//		User [id=1, name=Ϫ, birthday=2010-01-01]
		
		//[2-1] ʽjsonת
		List<User> users = jackson.readValue(userArr, new TypeReference<List<User>>() {});
		System.out.println(users);
		//ӡ
//		[User [id=1, name=Ϫ, birthday=2010-01-01], User [id=2, name=, birthday=2012-08-01]]
	}
	
	@Test
	public void jackson_bean2Json() throws Exception {
		
		ObjectMapper jackson = new ObjectMapper();
		//[2-3] תjson
		String userJson = jackson.writeValueAsString(user);
		System.out.println(userJson);
		//ӡ
//		{"id":1,"name":"","birthday":1530717373507}
		
		//[2-4] תjson
		String usersJson = jackson.writeValueAsString(users);
		System.out.println(usersJson);
		//ӡ
//		[{"id":1,"name":"","birthday":1530717401460},{"id":2,"name":"Դ","birthday":1530717401460}]
		
	}
}
